AttachRequest

Struct AttachRequest 

pub struct AttachRequest;
Sentinel message sent by an attach client as its first MessageEnvelope. Hosts use this to distinguish attach requests from regular inbound MessageEnvelope connections.