pub struct AttachRx(pub DuplexRx<Host2Client>);Expand description
Rx<MessageEnvelope> adapter that unwraps
Host2Client::Envelope from a duplex receiver.
Tuple Fields
0: DuplexRx<Host2Client>Trait Implementations
Sourceimpl Rx<MessageEnvelope> for AttachRx
impl Rx<MessageEnvelope> for AttachRx
Sourcefn recv<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Result<MessageEnvelope, ChannelError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn recv<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Result<MessageEnvelope, ChannelError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Receive the next message from the channel. If the channel returns
an error it is considered broken and should be discarded.
Sourcefn addr(&self) -> ChannelAddr
fn addr(&self) -> ChannelAddr
The channel address from which this Rx is receiving.